@@ -225,19 +225,19 @@ class Route53ToAlb(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="hostedZone")
     def hosted_zone(self) -> aws_cdk.aws_route53.IHostedZone:
         return typing.cast(aws_cdk.aws_route53.IHostedZone, jsii.get(self, "hostedZone"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="loadBalancer")
     def load_balancer(
         self,
     ) -> aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer:
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer, jsii.get(self, "loadBalancer"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> aws_cdk.aws_ec2.IVpc:
         return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
@@ -284,9 +284,9 @@ class Route53ToAlbProps:
         :param vpc_props: Custom properties for a new VPC. Providing both this and existingVpc is an error. If an existingAlb or existing Private Hosted Zone is provided, those already exist in a VPC so this value cannot be provided. Default: - None
         '''
         if isinstance(alb_logging_bucket_props, dict):
-            alb_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**alb_logging_bucket_props)
+            alb_logging_bucket_props = BucketProps(**alb_logging_bucket_props)
         if isinstance(vpc_props, dict):
-            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+            vpc_props = VpcProps(**vpc_props)
         if __debug__:
             type_hints = typing.get_type_hints(Route53ToAlbProps.__init__)
             check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
